package com.xy.job;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import com.xy.entity.DeviceEventMsg;
import com.xy.entity.SysDictRedis;
import com.xy.mapper.DeviceEventMsgMapper;
import com.xy.utils.DataTime;
import com.xy.utils.JobUtils;
import com.xy.utils.SysDictUtils;
import com.xy.utils.enums.DictEnum;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * <p>
 * 机器-消息表job
 * </p>
 *
 * @author lijin
 * @since 2023-01-11
 */
@Slf4j
@Component
@AllArgsConstructor
public class DeviceEventMsgJob {

    private DeviceEventMsgMapper deviceEventMsgMapper;

    /**
     * 数据清除
     *
     * @return
     */
    @XxlJob("delDeviceEventMsgRecord")
    public ReturnT<String> delDeviceEventMsgRecord() {
        //数据保留的天数
        SysDictRedis sysDictRedis = SysDictUtils.get(DictEnum.DATA_CLEAR_SIZE.getKey(), "device_errors_record_day");
        Integer jobParam = JobUtils.getPrams().gtInt();
        Integer saveDay = jobParam != null ? jobParam
                : sysDictRedis != null ? Integer.valueOf(sysDictRedis.getValue())
                : 365;
        LambdaQueryWrapper<DeviceEventMsg> lambdaQueryWrapper = new LambdaQueryWrapper<DeviceEventMsg>()
                .le(DeviceEventMsg::getCreateTime, DataTime.getStringAround(0, 0, (~(saveDay - 1)), 0, 0, 0));
        int delete = deviceEventMsgMapper.delete(lambdaQueryWrapper);
        if (delete > 0) {
            log.info("机器消息数据清除完成，共{}条", delete);
        }
        return ReturnT.SUCCESS;
    }
}
